		private void Spread_InitializeLayout( object sender, InitializeLayoutEventArgs e )
		{
			// Layout Settings ------------------------------------------------------------------------------------------------------
			e.Layout.ViewStyle = Infragistics.Win.UltraWinGrid.ViewStyle.MultiBand;
			e.Layout.MaxBandDepth = 2;
			e.Layout.InterBandSpacing = 0;
			e.Layout.RowConnectorStyle = RowConnectorStyle.None;

			// Overrides -------------------------------------------------------------------------------------------------------------
			e.Layout.Override.RowSelectors = Infragistics.Win.DefaultableBoolean.False;
			e.Layout.Override.ExpansionIndicator = ShowExpansionIndicator.Never;
			e.Layout.Override.DefaultRowHeight = PlanningSpreadStandard.DefaultRowHeight;
			e.Layout.Override.DefaultColWidth = printOptions.FitToColWidth;
			e.Layout.Override.HeaderAppearance.TextHAlign = HAlign.Left;
			e.Layout.Override.CellAppearance.TextHAlign = HAlign.Left;

			// =====================================================================================
			// --- Band 0 (Betriebe, Abteilungen)
			// =====================================================================================
			UltraGridBand band0 = e.Layout.Bands[FormPlanning.KeyBand_0];
			band0.ColHeadersVisible = false;
			band0.RowLayoutStyle = RowLayoutStyle.GroupLayout;

			// Column 'organisation'
			band0.Columns[FormPlanning.KeyCol_Organisation].Tag = new FormPlanning.ColTag( ColTypes.Organisation );
			band0.Columns[FormPlanning.KeyCol_Organisation].Width = FormPlanning.ColWidthOrganisation;

			// Column 'employee property' (hidden)
			band0.Columns[FormPlanning.KeyCol_EmplProp1].Tag = new FormPlanning.ColTag( ColTypes.OrgProperty );
			band0.Columns[FormPlanning.KeyCol_EmplProp1].Hidden = true;

			// =====================================================================================
			// --- Band 1 ( Mitarbeiter / Planung )
			// =====================================================================================
			UltraGridBand band1 = e.Layout.Bands[FormPlanning.KeyBand_1];
			band1.ColHeadersVisible = false;
			band1.RowLayoutStyle = RowLayoutStyle.GroupLayout;
			band1.Indentation = 0;

			// Column 'organisation'
			band1.Columns[FormPlanning.KeyCol_Organisation].Tag = new FormPlanning.ColTag( ColTypes.Organisation );
			band1.Columns[FormPlanning.KeyCol_Organisation].Width = FormPlanning.ColWidthOrganisation;
			band1.Columns[FormPlanning.KeyCol_Organisation].MergedCellStyle = MergedCellStyle.Always;

			// Column 'employee property' (hidden)
			band1.Columns[FormPlanning.KeyCol_EmplProp1].Tag = new FormPlanning.ColTag( ColTypes.OrgProperty );
			band1.Columns[FormPlanning.KeyCol_EmplProp1].Hidden = true;

			// =====================================================================================
			// --- Group-Headers aufsetzen fr Monatsname, Kalenderwochen und -Tage
			// =====================================================================================
			// Jeden Tag mit Monat, Tag, Wochentag
			CultureInfo cultureInfo = System.Threading.Thread.CurrentThread.CurrentUICulture;

			// Temp. Vars fr Gruppenheader fr Monat, Wochenbegin und Kalenderwoche
			UltraGridGroup groupMonth = null;
			UltraGridGroup groupWeekNum = null;
			UltraGridGroup groupWeekDay = null;

			try
            {
				// Group Organisation
				UltraGridGroup groupOrg = band0.Groups.Add( "GroupOrg" );
				groupOrg.Header.Caption = string.Empty;
				groupOrg.RowLayoutGroupInfo.OriginX = 0;
				groupOrg.RowLayoutGroupInfo.OriginY = 0;
				groupOrg.RowLayoutGroupInfo.SpanX = 1;
				groupOrg.RowLayoutGroupInfo.SpanY = 6;

				// Column Organisation
				UltraGridColumn col0 = band0.Columns[FormPlanning.KeyCol_Organisation];
				col0.Width = FormPlanning.ColWidthOrganisation;
				col0.RowLayoutColumnInfo.OriginX = 0;
				col0.RowLayoutColumnInfo.OriginY = 0;
				col0.RowLayoutColumnInfo.SpanX = 1;
				col0.RowLayoutColumnInfo.SpanY = 6;
				col0.RowLayoutColumnInfo.ParentGroup = groupOrg;

				UltraGridColumn col1 = band1.Columns[FormPlanning.KeyCol_Organisation];
				col1.Width = FormPlanning.ColWidthOrganisation;
				col1.RowLayoutColumnInfo.ParentGroup = groupOrg;

				// Tageszhler
				int dayInRangeCount = 1;
				int dayInMonthCount = 1;

				for ( DateTime date = this.servicePlan.OpenInfo.OpenRange.From; date <= this.servicePlan.OpenInfo.OpenRange.To; date = date.AddDays( 1 ) )
                {
					string colKey = date.ToShortDateString();

	                // Gruppenheader fr den Monat
					string key = string.Format( "GroupMonth{0}.{1}", date.Year, date.Month );
					if ( !band0.Groups.Exists( key ) )
					{
						dayInMonthCount = 1;
						DateTime endOfMOnth = new DateTime( date.Year, date.Month, DateTime.DaysInMonth( date.Year, date.Month ) );
						int numDays = this.servicePlan.OpenInfo.OpenRange.Contains( endOfMOnth ) ? DateTime.DaysInMonth( date.Year, date.Month ) : this.servicePlan.OpenInfo.OpenRange.To.Day; 

						groupMonth = band0.Groups.Add( key );
						groupMonth.Header.Caption = cultureInfo.DateTimeFormat.MonthNames[date.Month-1];
						groupMonth.RowLayoutGroupInfo.OriginX = dayInRangeCount;
						groupMonth.RowLayoutGroupInfo.OriginY = 0;
						groupMonth.RowLayoutGroupInfo.SpanX = numDays;
						groupMonth.RowLayoutGroupInfo.SpanY = 6;
					}

					// Gruppenheader fr Kalenderwoche
					if ( groupWeekNum == null || date.DayOfWeek == cultureInfo.DateTimeFormat.FirstDayOfWeek )
					{
						int weekOfYear = cultureInfo.DateTimeFormat.Calendar.GetWeekOfYear( date, cultureInfo.DateTimeFormat.CalendarWeekRule, cultureInfo.DateTimeFormat.FirstDayOfWeek );
						int weekDays = this.servicePlan.OpenInfo.OpenRange.Contains( date.AddDays( 6 ) ) ? 7 : ( this.servicePlan.OpenInfo.OpenRange.To.Date - date.Date ).Days + 1;
						key = string.Format( "GroupWeekNum{0}{1}", date.Year, weekOfYear );

						if ( !band0.Groups.Exists( key ) )
						{
							// -> Tag im Monat am Beginn der Kalenderwoche
							groupWeekDay = band0.Groups.Add( string.Format( "GroupWeekDay{0}{1}", date.Year, weekOfYear ) );
							groupWeekDay.Header.Caption = date.Day.ToString();
							groupWeekDay.RowLayoutGroupInfo.OriginX = dayInMonthCount;
							groupWeekDay.RowLayoutGroupInfo.OriginY = 2;
							groupWeekDay.RowLayoutGroupInfo.SpanX = weekDays;
							groupWeekDay.RowLayoutGroupInfo.SpanY = 2;
							groupWeekDay.RowLayoutGroupInfo.ParentGroup = groupMonth;

							// -> Nummer der Kalenderwoche
							groupWeekNum = band0.Groups.Add( key );
							groupWeekNum.Header.Caption = weekOfYear.ToString();
							groupWeekNum.RowLayoutGroupInfo.OriginX = dayInMonthCount;
							groupWeekNum.RowLayoutGroupInfo.OriginY = 4;
							groupWeekNum.RowLayoutGroupInfo.SpanX = weekDays;
							groupWeekNum.RowLayoutGroupInfo.SpanY = 2;
							groupWeekNum.RowLayoutGroupInfo.ParentGroup = groupMonth;
						}
					}

					// Column Band 0
					col0 = band0.Columns[colKey];
					col0.RowLayoutColumnInfo.OriginX = dayInMonthCount;
					col0.RowLayoutColumnInfo.OriginY = 0;
					col0.RowLayoutColumnInfo.SpanX = 1;
					col0.RowLayoutColumnInfo.SpanY = 1;
					col0.Width = printOptions.FitToColWidth;
					col0.RowLayoutColumnInfo.ParentGroup = groupMonth;

					// Column Band 1
					col1 = band1.Columns[colKey];
					col1.Width = printOptions.FitToColWidth;

					// Check option for weekend colors
					if ( printOptions.UseWeekendColors && ( date.DayOfWeek == DayOfWeek.Saturday || date.DayOfWeek == DayOfWeek.Sunday ) )
					{
						Color backColor = date.DayOfWeek == DayOfWeek.Saturday ? ClientParam.Instance.ParamColors.GetColor( ClientParam.ParamTypes.ColorSaturday ) :
							ClientParam.Instance.ParamColors.GetColor( ClientParam.ParamTypes.ColorSunday );

						band0.Columns[colKey].CellAppearance.BackColor = backColor;
						band1.Columns[colKey].CellAppearance.BackColor = backColor;
					}

					dayInRangeCount++;
					dayInMonthCount++;
				}
            }
            catch ( Exception x )
            {
                Logger.Error( x, false );
            }

		}
